# -*- coding: utf-8 -*-
import unittest

from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app import testing
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.testing import z2

import retrans.poi


RETRANS_POI_FIXTURE = testing.PloneWithPackageLayer(
    bases=(PLONE_APP_CONTENTTYPES_FIXTURE, ),
    zcml_package=retrans.poi,
    zcml_filename='configure.zcml',
    gs_profile_id='retrans.poi:default',
    name="RetransPoiFixture")
RETRANS_POI_INTEGRATION_TESTING = IntegrationTesting(
    bases=(RETRANS_POI_FIXTURE,),
    name='RetransPoiLayer:IntegrationTesting')
RETRANS_POI_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(RETRANS_POI_FIXTURE,),
    name='RetransPoiLayer:FunctionalTesting')


class RetransPoiIssueLayer(testing.PloneSandboxLayer):
    """
    Add an issue tracker and some issues.
    """

    defaultBases = (RETRANS_POI_FIXTURE, )

    def setUpPloneSite(self, portal):
        """
        Add an issue tracker and some issues.
        """
        z2.login(portal.__parent__.acl_users, testing.SITE_OWNER_NAME)

        self['tracker'] = tracker = portal[portal.invokeFactory(
            'Tracker', 'foo-issue-tracker', title='Foo Issue Tracker',
            assignees=[])]
        self['empty_issue'] = tracker[tracker.invokeFactory(
            'Issue', '1', title='Bar Empty Issue',
            details=u'Bar empty issue details')]


RETRANS_POI_ISSUE_FIXTURE = RetransPoiIssueLayer()
RETRANS_POI_ISSUE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(RETRANS_POI_ISSUE_FIXTURE,),
    name='RetransPoiIssueLayer:IntegrationTesting')
RETRANS_POI_ISSUE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(RETRANS_POI_ISSUE_FIXTURE,),
    name='RetransPoiIssueLayer:FunctionalTesting')


RETRANS_POI_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        RETRANS_POI_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE
    ),
    name='RetransPoiLayer:AcceptanceTesting'
)


class RetransPoiTestCase(unittest.TestCase):
    """
    Common testing support.
    """

    layer = RETRANS_POI_ISSUE_INTEGRATION_TESTING

    def setUpBrowser(self):
        """
        Start a logged in browser session.
        """
        app = self.layer['app']
        self.browser = z2.Browser(app)
        self.browser.handleErrors = False  # Don't get HTTP 500 pages

        portal = self.layer['portal']
        portal_url = portal.absolute_url()

        self.browser.open(portal_url + '/login_form')
        self.browser.getControl(
            name='__ac_name').value = testing.SITE_OWNER_NAME
        self.browser.getControl(
            name='__ac_password').value = testing.SITE_OWNER_PASSWORD
        self.browser.getControl(name='submit').click()
        self.assertIn(
            "You are now logged in", self.browser.contents.decode('utf-8'),
            'Missing login confirmation message')
